@@ -5,7 +5,7 @@
         NonlinearSolveFirstOrder;
         piracies = false, ambiguities = false
     )
-    Aqua.test_piracies(NonlinearSolveFirstOrder)
+    Aqua.test_piracies(NonlinearSolveFirstOrder; treat_as_own = [NonlinearLeastSquaresProblem])
     Aqua.test_ambiguities(NonlinearSolveFirstOrder; recursive = false)
 end
 
